import { tutorialData } from "@/constants/tutorial-data";
import { notFound } from "next/navigation";
import { LANGUAGE_VERSIONS } from "@/constants/language-options";
import { markdownToHtml } from "@/lib/markdown-to-html";
import TaskPage from "@/components/task-page";

const languages = Object.keys(LANGUAGE_VERSIONS);

const Page = async ({ params }: { params: { taskId: string[] } }) => {
  if (!params.taskId[0] || !languages.includes(params.taskId[0])) {
    notFound();
  }

  const langTutorial = tutorialData.find(
    (t) => t.language === params.taskId[0],
  )!;

  const tutorial = langTutorial.tutorial.find(
    (t) => t.id === (Number(params.taskId[1]) || 1),
  );

  const tutorialIndex = langTutorial.tutorial.findIndex(
    (t) => t.id === (Number(params.taskId[1]) || 1),
  );

  if (!tutorial || tutorialIndex === -1) {
    notFound();
  }

  const content = await markdownToHtml(tutorial?.content || "");
  return (
    <TaskPage
      params={params}
      langTutorial={langTutorial}
      tutorial={tutorial}
      tutorialIndex={tutorialIndex}
      content={content}
    />
  );
};

export default Page;
