"use client";

import React, { useEffect, useState } from "react";
// import { getQuestions, newAnswer } from "../features/questions/questionsSlice";
import { Loader } from "./loader";
import { ErrorMessage } from "./error-message";
import { ProgressBar } from "./progress";
import { Timer } from "./timer";
import { Next } from "./next";
import { useQuizStore } from "@/lib/quiz-store";
import { useShallow } from "zustand/react/shallow";
import { Button } from "../ui/button";
import { cn } from "@/lib/utils";

export const Question = ({ difficulty }: { difficulty: string }) => {
  //   const { difficulty } = useParams();
  //   const { gameMode } = useSelector((store) => store.difficulty);
  //   const { status, index, currentQuestion, answer } = useSelector(
  // (store) => store.questions,
  //   );
  const [currentCorrectAns, setCurrentCorrectAns] = useState("");

  const [isStart, setIsStart] = useState(false);

  const {
    restartTimer,
    // gameMode,
    status,
    index,
    currentQuestion,
    answer,
    newAnswer,
  } = useQuizStore(
    useShallow((store) => ({
      restartTimer: store.restartTimer,
      gameMode: store.gameMode,
      status: store.status,
      index: store.index,
      currentQuestion: store.currentQuestion,
      answer: store.answer,
      newAnswer: store.newAnswer,
    })),
  );

  useEffect(() => {
    restartTimer();
    // getQuestions(gameMode);
  }, []);

  useEffect(() => {
    window.scrollTo(0, 0);
  }, [index]);

  const statement = currentQuestion?.question;
  const options = currentQuestion?.options;
  const hasAnswered = answer !== null;
  // const styleCat = {
  //   backgroundColor: difficulty === "medium" ? "#e3ce0e" : "#fc2121",
  // };
  return (
    <div className=" max-w-4xl mx-auto mt-8 px-4">
      {status === "loading" && <Loader />}
      {status === "error" && <ErrorMessage />}
      {status === "ready" && (
        <>
          <ProgressBar />
          <div className="space-y-4 mt-8">
            {/* <div
              className="category"
              // style={difficulty !== "easy" ? styleCat : {}}
            >
              {difficulty} quiz
            </div> */}
            <h4 className="text-xl font-semibold">{statement}</h4>
            <div className="flex flex-col gap-1">
              {options?.map((option: any, index: number) => {
                return (
                  <Button
                    // variant={`${answer === option ? "default" : "secondary"}`}
                    variant={`${
                      currentCorrectAns === option ? "default" : "secondary"
                    }`}
                    key={index}
                    className={cn(
                      "justify-start text-lg py-6 disabled:pointer-events-auto disabled:cursor-not-allowed",
                    )}
                    // className={cn(answer === option ? "answer" : "")}
                    //         className={`${answer === option ? "answer" : ""}
                    // ${
                    //   hasAnswered
                    //     ? currentQuestion.correctAnswer === option
                    //       ? "correct"
                    //       : ""
                    //     : ""
                    // }
                    // `}
                    disabled={!isStart}
                    onClick={() => setCurrentCorrectAns(option)}
                    // onClick={() => newAnswer(option)}
                  >
                    {option}
                  </Button>
                );
              })}
            </div>
          </div>
          <div className="flex justify-between mt-6 items-center">
            <div>
              {/* {answer && <Next currentCorrectAns={currentCorrectAns} />} */}
              {currentCorrectAns !== "" && (
                <Next currentCorrectAns={currentCorrectAns} />
              )}
            </div>

            {isStart ? (
              <Timer />
            ) : (
              <Button onClick={() => setIsStart(true)}>Start</Button>
            )}
          </div>
        </>
      )}
    </div>
  );
};
