import { Button } from "@/components/ui/button";
import { useState } from "react";
import { cn } from "@/lib/utils";
import { useToast } from "@/components/ui/use-toast";
import { executeCode } from "@/lib/api";

const Output = ({ codeValue, language }: any) => {
  const { toast } = useToast();
  const [output, setOutput] = useState<any>(null);
  const [isLoading, setIsLoading] = useState(false);
  const [isError, setIsError] = useState(false);

  const runCode = async () => {
    if (!codeValue) return;
    try {
      setIsLoading(true);
      const { run: result } = await executeCode(language, codeValue);
      setOutput(result.output.split("\n"));
      result.stderr ? setIsError(true) : setIsError(false);
    } catch (error) {
      // console.log(error);
      toast({
        variant: "destructive",
        title: "An error occurred.",
        description: (error as Error).message || "Unable to run code",
      });
    } finally {
      setIsLoading(false);
    }
  };

  return (
    <div className="p-4">
      {/* <p>Output</p> */}
      <Button variant="outline" onClick={runCode} disabled={isLoading}>
        {isLoading ? "Running..." : "Run Code"}
      </Button>
      <div
        className={cn(
          "mt-4 p-4 rounded-md",
          isError ? "text-red-700 border border-red-700 bg-red-50" : "border",
        )}
        // color={isError ? "red.400" : ""}
        // borderColor={isError ? "red.500" : "#333"}
      >
        {output
          ? output.map((line: any, i: number) => <p key={i}>{line}</p>)
          : 'Click "Run Code" to see the output here'}
      </div>
    </div>
  );
};
export default Output;
