import * as z from "zod";
import { isValidPhoneNumber } from "react-phone-number-input";

export const profileSchema = z.object({
  firstname: z
    .string({ required_error: "Please enter your first name" })
    .trim()
    .min(1, { message: "Please enter your first name" }),
  lastname: z
    .string({ required_error: "Please enter your last name" })
    .trim()
    .min(1, { message: "Please enter your last name" }),
  email: z
    .string({ required_error: "Please enter your email" })
    .email({ message: "Please enter a valid email" }),
  contactno: z
    .string({ required_error: "Please enter your phone number" })
    .refine((value) => isValidPhoneNumber(value), {
      message: "Please enter a valid phone number",
    }),
  country: z
    .string({ required_error: "Please select your country" })
    .trim()
    .min(1, { message: "Please select your country" }),
  state: z
    .string({ required_error: "Please select your state" })
    .trim()
    .min(1, { message: "Please select your state" }),
  city: z
    .string({ required_error: "Please select your city" })
    .trim()
    .min(1, { message: "Please select your city" }),
  // jobs array is for the dynamic fields
  jobs: z.array(
    z.object({
      jobcountry: z.string().min(1, { message: "Please select a country" }),
      jobstate: z.string().min(1, { message: "Please select a job state" }),
      jobcity: z.string().min(1, { message: "Please select a city" }),
      jobtitle: z
        .string()
        .trim()
        .min(1, { message: "Please enter your job title" }),
      employer: z
        .string()
        .trim()
        .min(1, { message: "Please enter your employer name" }),
      startdate: z
        .string()
        .refine((value) => /^\d{4}-\d{2}-\d{2}$/.test(value), {
          message: "Start date should be in the format YYYY-MM-DD",
        }),
      enddate: z.string().refine((value) => /^\d{4}-\d{2}-\d{2}$/.test(value), {
        message: "End date should be in the format YYYY-MM-DD",
      }),
    }),
  ),
});

export type ProfileFormValues = z.infer<typeof profileSchema>;
