"use client";

import { createContext, useContext } from "react";
import { createStore, useStore as useZustandStore } from "zustand";
import { PreloadedStoreInterface } from "./store-provider";
import { questions } from "@/constants/data";

function shuffleArray(array: any) {
  const newArray = [...array];
  // for (let i = newArray.length - 1; i > 0; i--) {
  //   const j = Math.floor(Math.random() * (i + 1));
  //   [newArray[i], newArray[j]] = [newArray[j], newArray[i]];
  // }
  return newArray;
}

export interface StoreInterface {
  gameMode: null | string;
  questionsArray: any[];
  //loading, error, ready
  status: string;
  index: number;
  currentQuestion: any;
  answer: null;
  points: number;
  highscore: number;
  secondsRemaining: number;
  totalCorrectAns: number;
  lessSeconds: () => void;
  restartTimer: () => void;
  selectGameMode: (gameMode: string) => void;
  newAnswer: (answer: any) => void;
  nextQuestion: () => void;
  gameEnded: () => void;
  lastUpdate: number;
  light: boolean;
  count: number;
  // tick: (lastUpdate: number) => void;
  // increment: () => void;
  // decrement: () => void;
  reset: () => void;
  correctAns: string[];

  isTaskPageLoading: boolean;
  updateTaskPageLoading: (value: boolean) => void;
}

function getDefaultInitialState() {
  return {
    lastUpdate: new Date(1970, 1, 1).getTime(),
    light: false,
    count: 0,
    gameMode: null,
    questionsArray: questions,
    //loading, error, ready
    status: "ready",
    index: 0,
    currentQuestion: {
      id: questions[0].id,
      correctAnswer: questions[0].correctAnswer,
      question: questions[0].question.text,
      options: shuffleArray([
        ...questions[0].incorrectAnswers,
        questions[0].correctAnswer,
      ]),
    },
    answer: null,
    points: 0,
    highscore: 0,
    secondsRemaining: 210,
    totalCorrectAns: 0,
    correctAns: [],
    isTaskPageLoading: false,
  };
}

export type StoreType = ReturnType<typeof initializeStore>;

const storeContext = createContext<StoreType | null>(null);

export const Provider = storeContext.Provider;

export function useQuizStore<T>(selector: (state: StoreInterface) => T) {
  const store = useContext(storeContext);

  if (!store) throw new Error("Store is missing the provider");

  return useZustandStore(store, selector);
}

export function initializeStore(preloadedState: PreloadedStoreInterface) {
  return createStore<StoreInterface>((set, get) => ({
    ...getDefaultInitialState(),
    ...preloadedState,
    selectGameMode: (gameMode) =>
      set({
        gameMode,
      }),
    newAnswer: (answer) => {
      // console.log(get().totalCorrectAns);
      set({
        answer,
        // points:
        //   answer === get().currentQuestion.correctAnswer
        //     ? get().points + 20
        //     : get().points,
        correctAns:
          answer === get().currentQuestion.correctAnswer &&
          !get().correctAns.includes(answer)
            ? [...get().correctAns, answer]
            : get().correctAns,
        totalCorrectAns:
          answer === get().currentQuestion.correctAnswer
            ? get().totalCorrectAns + 1
            : get().totalCorrectAns,
      });
    },
    nextQuestion: () => {
      let temp = get().questionsArray[get().index + 1];
      let newArray = {
        id: temp.id,
        correctAnswer: temp.correctAnswer,
        question: temp.question.text,
        options: shuffleArray([...temp.incorrectAnswers, temp.correctAnswer]),
      };
      set({
        index: (get().index += 1),
        currentQuestion: newArray,
        answer: null,
      });
    },
    gameEnded: () =>
      set({
        highscore:
          get().points > get().highscore ? get().points : get().highscore,
      }),
    lessSeconds: () => set({ secondsRemaining: (get().secondsRemaining -= 1) }),
    restartTimer: () => set({ secondsRemaining: 210 }),
    reset: () =>
      set({
        lastUpdate: new Date(1970, 1, 1).getTime(),
        light: false,
        count: 0,
        gameMode: null,
        questionsArray: questions,
        //loading, error, ready
        status: "ready",
        index: 0,
        currentQuestion: {
          id: questions[0].id,
          correctAnswer: questions[0].correctAnswer,
          question: questions[0].question.text,
          options: shuffleArray([
            ...questions[0].incorrectAnswers,
            questions[0].correctAnswer,
          ]),
        },
        answer: null,
        points: 0,
        highscore: 0,
        secondsRemaining: 210,
        totalCorrectAns: 0,
      }),
    // tick: (lastUpdate) =>
    //   set({
    //     lastUpdate,
    //     light: !get().light,
    //   }),
    // increment: () =>
    //   set({
    //     count: get().count + 1,
    //   }),
    // decrement: () =>
    //   set({
    //     count: get().count - 1,
    //   }),
    // reset: () =>
    //   set({
    //     count: getDefaultInitialState().count,
    //   }),

    updateTaskPageLoading: (value) => {
      console.log(value)
      set({
        isTaskPageLoading: value,
      })},
  }));
}
